aboutsummaryrefslogtreecommitdiffstats
path: root/src/PlayerThread.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'src/PlayerThread.hxx')
-rw-r--r--src/PlayerThread.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/PlayerThread.hxx b/src/PlayerThread.hxx
index 97e773606..efdcf05ca 100644
--- a/src/PlayerThread.hxx
+++ b/src/PlayerThread.hxx
@@ -26,7 +26,7 @@
* audio outputs via audio_output_all_play().
*
* It is controlled by the main thread (the playlist code), see
* player_control.h. The playlist enqueues new songs into the player
* thread and sends it commands.
*
* The player thread itself does not do any I/O. It synchronizes with
@@ -37,9 +37,9 @@
#ifndef MPD_PLAYER_THREAD_HXX
#define MPD_PLAYER_THREAD_HXX
-struct player_control;
+struct PlayerControl;
void
-player_create(player_control &pc);
+player_create(PlayerControl &pc);
#endif
@@ -26,7 +26,7 @@
*
* It is controlled by the main thread (the playlist code), see
- * player_control.h. The playlist enqueues new songs into the player
+ * PlayerControl.hxx. The playlist enqueues new songs into the player
* thread and sends it commands.
*